==> jc-1.4.0.tar.gz: java/awt/AWTKeyStroke__241.h <==
// final class java.awt.AWTKeyStroke$1

// class file dependencies
// @dep_class ee3a6ee6a5a76851 java_awt_AWTKeyStroke__241
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c7382c60132d0b2c java_util_AbstractMap
// @dep_class d7cd853200c3e71f java_util_HashMap
// @dep_class 2c839a8260baa57f java_util_LinkedHashMap

// header file dependencies
// @dep_header java_util_LinkedHashMap

#include "java/util/LinkedHashMap.h"

#ifndef _JC_java_awt_AWTKeyStroke__241_H_
#define _JC_java_awt_AWTKeyStroke__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map__24Entry$object;

// Typedefs
typedef struct _jc_java_awt_AWTKeyStroke__241$sub_refs	_jc_java_awt_AWTKeyStroke__241$sub_refs;
typedef struct _jc_java_awt_AWTKeyStroke__241$sub_nonrefs	_jc_java_awt_AWTKeyStroke__241$sub_nonrefs;
typedef struct _jc_java_awt_AWTKeyStroke__241$refs	_jc_java_awt_AWTKeyStroke__241$refs;
typedef struct _jc_java_awt_AWTKeyStroke__241$nonrefs	_jc_java_awt_AWTKeyStroke__241$nonrefs;
typedef struct _jc_java_awt_AWTKeyStroke__241$object	_jc_java_awt_AWTKeyStroke__241$object;

typedef struct _jc_java_awt_AWTKeyStroke__241$fields_struct	_jc_java_awt_AWTKeyStroke__241$fields_struct;
typedef const struct _jc_java_awt_AWTKeyStroke__241$vmethods	_jc_java_awt_AWTKeyStroke__241$vmethods;
typedef const struct _jc_java_awt_AWTKeyStroke__241$vtable	_jc_java_awt_AWTKeyStroke__241$vtable;
typedef const struct _jc_java_awt_AWTKeyStroke__241$vtype	_jc_java_awt_AWTKeyStroke__241$vtype;

// Class fields structure
struct _jc_java_awt_AWTKeyStroke__241$fields_struct {
	jint	MAX__5fCACHE__5fSIZE;
};
extern _jc_java_awt_AWTKeyStroke__241$fields_struct _jc_java_awt_AWTKeyStroke__241$class_fields;

// Constructors
extern void _jc_java_awt_AWTKeyStroke__241$method$_init$bdc53dc6d94c368b(_jc_env *, struct _jc_java_awt_AWTKeyStroke__241$object *, jint, jfloat, jboolean);

// Virtual methods
extern jboolean _jc_java_awt_AWTKeyStroke__241$method$removeEldestEntry$c2aa6e9c82650f0c(_jc_env *, struct _jc_java_awt_AWTKeyStroke__241$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_AWTKeyStroke__241$method_info$removeEldestEntry$c2aa6e9c82650f0c;

// Virtual methods structure
struct _jc_java_awt_AWTKeyStroke__241$vmethods {
	jboolean	(*removeEldestEntry$c2aa6e9c82650f0c)(_jc_env *, struct _jc_java_awt_AWTKeyStroke__241$object *, struct _jc_object *);
};

// Vtable
struct _jc_java_awt_AWTKeyStroke__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractMap$vmethods	java_util_AbstractMap;
	_jc_java_util_HashMap$vmethods	java_util_HashMap;
	_jc_java_util_LinkedHashMap$vmethods	java_util_LinkedHashMap;
	_jc_java_awt_AWTKeyStroke__241$vmethods	java_awt_AWTKeyStroke__241;
};

// Vtype
struct _jc_java_awt_AWTKeyStroke__241$vtype {
	_jc_type			type;
	_jc_java_awt_AWTKeyStroke__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_AWTKeyStroke__241$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_AWTKeyStroke__241$refs {
    _jc_java_awt_AWTKeyStroke__241$sub_refs	java_awt_AWTKeyStroke__241;
    _jc_java_util_LinkedHashMap$sub_refs	java_util_LinkedHashMap;
    _jc_java_util_HashMap$sub_refs	java_util_HashMap;
    _jc_java_util_AbstractMap$sub_refs	java_util_AbstractMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_AWTKeyStroke__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_AWTKeyStroke__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractMap$sub_nonrefs	java_util_AbstractMap;
    _jc_java_util_HashMap$sub_nonrefs	java_util_HashMap;
    _jc_java_util_LinkedHashMap$sub_nonrefs	java_util_LinkedHashMap;
    _jc_java_awt_AWTKeyStroke__241$sub_nonrefs	java_awt_AWTKeyStroke__241;
};

// Object instance structure
struct _jc_java_awt_AWTKeyStroke__241$object {
	_jc_java_awt_AWTKeyStroke__241$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_AWTKeyStroke__241$vtype	*vtype;
	_jc_java_awt_AWTKeyStroke__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_AWTKeyStroke__241$vtype _jc_java_awt_AWTKeyStroke__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_AWTKeyStroke__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_AWTKeyStroke__241$class_object;

#endif	/* _JC_java_awt_AWTKeyStroke__241_H_ */

==> jc-1.4.5.tar.gz: java/awt/AWTKeyStroke__241.h <==
// final class java.awt.AWTKeyStroke$1

// class file dependencies
// @dep_class ee3a6ee6a5a76851 java_awt_AWTKeyStroke__241
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c7382c60132d0b2c java_util_AbstractMap
// @dep_class d7cd853200c3e71f java_util_HashMap
// @dep_class 2c839a8260baa57f java_util_LinkedHashMap

// header file dependencies
// @dep_header java_util_LinkedHashMap

#include "java/util/LinkedHashMap.h"

#ifndef _JC_java_awt_AWTKeyStroke__241_H_
#define _JC_java_awt_AWTKeyStroke__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map__24Entry$object;

// Typedefs
typedef struct _jc_java_awt_AWTKeyStroke__241$sub_refs	_jc_java_awt_AWTKeyStroke__241$sub_refs;
typedef struct _jc_java_awt_AWTKeyStroke__241$sub_nonrefs	_jc_java_awt_AWTKeyStroke__241$sub_nonrefs;
typedef struct _jc_java_awt_AWTKeyStroke__241$refs	_jc_java_awt_AWTKeyStroke__241$refs;
typedef struct _jc_java_awt_AWTKeyStroke__241$nonrefs	_jc_java_awt_AWTKeyStroke__241$nonrefs;
typedef struct _jc_java_awt_AWTKeyStroke__241$object	_jc_java_awt_AWTKeyStroke__241$object;

typedef struct _jc_java_awt_AWTKeyStroke__241$fields_struct	_jc_java_awt_AWTKeyStroke__241$fields_struct;
typedef const struct _jc_java_awt_AWTKeyStroke__241$vmethods	_jc_java_awt_AWTKeyStroke__241$vmethods;
typedef const struct _jc_java_awt_AWTKeyStroke__241$vtable	_jc_java_awt_AWTKeyStroke__241$vtable;
typedef const struct _jc_java_awt_AWTKeyStroke__241$vtype	_jc_java_awt_AWTKeyStroke__241$vtype;

// Class fields structure
struct _jc_java_awt_AWTKeyStroke__241$fields_struct {
	jint	MAX__5fCACHE__5fSIZE;
};
extern _jc_java_awt_AWTKeyStroke__241$fields_struct _jc_java_awt_AWTKeyStroke__241$class_fields;

// Constructors
extern void _jc_java_awt_AWTKeyStroke__241$method$_init$bdc53dc6d94c368b(_jc_env *, struct _jc_java_awt_AWTKeyStroke__241$object *, jint, jfloat, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_awt_AWTKeyStroke__241$method$removeEldestEntry$c2aa6e9c82650f0c(_jc_env *, struct _jc_java_awt_AWTKeyStroke__241$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_AWTKeyStroke__241$method_info$removeEldestEntry$c2aa6e9c82650f0c;

// Virtual methods structure
struct _jc_java_awt_AWTKeyStroke__241$vmethods {
	jboolean	(*removeEldestEntry$c2aa6e9c82650f0c)(_jc_env *, struct _jc_java_awt_AWTKeyStroke__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_AWTKeyStroke__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractMap$vmethods	java_util_AbstractMap;
	_jc_java_util_HashMap$vmethods	java_util_HashMap;
	_jc_java_util_LinkedHashMap$vmethods	java_util_LinkedHashMap;
	_jc_java_awt_AWTKeyStroke__241$vmethods	java_awt_AWTKeyStroke__241;
};

// Vtype
struct _jc_java_awt_AWTKeyStroke__241$vtype {
	_jc_type			type;
	_jc_java_awt_AWTKeyStroke__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_AWTKeyStroke__241$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_AWTKeyStroke__241$refs {
    _jc_java_awt_AWTKeyStroke__241$sub_refs	java_awt_AWTKeyStroke__241;
    _jc_java_util_LinkedHashMap$sub_refs	java_util_LinkedHashMap;
    _jc_java_util_HashMap$sub_refs	java_util_HashMap;
    _jc_java_util_AbstractMap$sub_refs	java_util_AbstractMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_AWTKeyStroke__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_AWTKeyStroke__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractMap$sub_nonrefs	java_util_AbstractMap;
    _jc_java_util_HashMap$sub_nonrefs	java_util_HashMap;
    _jc_java_util_LinkedHashMap$sub_nonrefs	java_util_LinkedHashMap;
    _jc_java_awt_AWTKeyStroke__241$sub_nonrefs	java_awt_AWTKeyStroke__241;
};

// Object instance structure
struct _jc_java_awt_AWTKeyStroke__241$object {
	_jc_java_awt_AWTKeyStroke__241$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_AWTKeyStroke__241$vtype	*vtype;
	_jc_java_awt_AWTKeyStroke__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_AWTKeyStroke__241$vtype _jc_java_awt_AWTKeyStroke__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_AWTKeyStroke__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_AWTKeyStroke__241$class_object;

#endif	/* _JC_java_awt_AWTKeyStroke__241_H_ */
